@@ -1,7 +1,5 @@
 import traceback
 from feagi_agent import router
-from feagi_agent import configuration as feagi_config
-# from robot_controllers.freenove_smartcar import configuration as agent_config
 from time import sleep
 
 
@@ -13,7 +11,7 @@ def sub_initializer(opu_address, flags=router.zmq.NOBLOCK):
     return router.Sub(address=opu_address, flags=flags)
 
 
-def feagi_registration(feagi_host, api_port):
+def feagi_registration(feagi_host, api_port, agent_settings, capabilities):
     host_info = router.app_host_info()
     runtime_data = {
         "host_network": {},
@@ -29,11 +27,11 @@ def feagi_registration(feagi_host, api_port):
             runtime_data["feagi_state"] = \
                 router.register_with_feagi(feagi_ip=feagi_host,
                                            feagi_api_port=api_port,
-                                           agent_type=feagi_config.agent_settings['agent_type'],
-                                           agent_id=feagi_config.agent_settings['agent_id'],
+                                           agent_type=agent_settings['agent_type'],
+                                           agent_id=agent_settings['agent_id'],
                                            agent_ip=runtime_data["host_network"]["ip_address"],
-                                           agent_data_port=feagi_config.agent_settings['agent_data_port'],
-                                           agent_capabilities=feagi_config.capabilities)
+                                           agent_data_port=agent_settings['agent_data_port'],
+                                           agent_capabilities=capabilities)
         except Exception as e:
             print("ERROR__: ", e, traceback.print_exc())
             pass
@@ -47,18 +45,14 @@ def block_to_array(block_ref):
     return array
 
 
-def get_agent():
-    return feagi_config
-
-
-def feagi_setting_for_registration():
+def feagi_setting_for_registration(feagi_settings, agent_settings):
     """
     Generate all needed information and return the full data to make it easier to connect with
     FEAGI
     """
-    feagi_ip_host = feagi_config.feagi_settings["feagi_host"]
-    api_port = feagi_config.feagi_settings["feagi_api_port"]
-    app_data_port = feagi_config.agent_settings["agent_data_port"]
+    feagi_ip_host = feagi_settings["feagi_host"]
+    api_port = feagi_settings["feagi_api_port"]
+    app_data_port = agent_settings["agent_data_port"]
     return feagi_ip_host, api_port, app_data_port
 
 
@@ -102,7 +96,7 @@ def msg_processor(self, msg, msg_type):
         sensor_id = int(''.join(filter(str.isdigit, sensor_topic)))
 
         # print("\n***\nAverage Intensity = ", avg_intensity)
-        if avg_intensity > feagi_config.capabilities["infrared"]["threshold"]:
+        if avg_intensity > configuration.capabilities["infrared"]["threshold"]:
             return {
                 'ir': {
                     sensor_id: False
@@ -216,14 +210,14 @@ def control_data_processor(data):
     control_data = data['control_data']
     if control_data is not None:
         if 'motor_power_coefficient' in control_data:
-            feagi_config.capabilities["motor"]["power_coefficient"] = float(control_data['motor_power_coefficient'])
+            configuration.capabilities["motor"]["power_coefficient"] = float(control_data['motor_power_coefficient'])
         if 'robot_starting_position' in control_data:
             for position_index in control_data['robot_starting_position']:
-                feagi_config.capabilities["position"][position_index]["x"] = \
+                configuration.capabilities["position"][position_index]["x"] = \
                     float(control_data['robot_starting_position'][position_index][0])
-                feagi_config.capabilities["position"][position_index]["y"] = \
+                configuration.capabilities["position"][position_index]["y"] = \
                     float(control_data['robot_starting_position'][position_index][1])
-                feagi_config.capabilities["position"][position_index]["z"] = \
+                configuration.capabilities["position"][position_index]["z"] = \
                     float(control_data['robot_starting_position'][position_index][2])
-        return feagi_config.capabilities["motor"]["power_coefficient"], \
-               feagi_config.capabilities["position"]
+        return configuration.capabilities["motor"]["power_coefficient"], \
+               configuration.capabilities["position"]
